Module tinychain::cluster

source ·
Maintains the consistency of the network by coordinating transaction commits.

Re-exports

Modules

Structs

  • The data structure responsible for maintaining consensus per-transaction across the network.
  • The static configuration of a Cluster

Constants

  • The name of the endpoint which serves a [Link] to each of this [Cluster]’s replicas.

Traits

  • A state which supports replication in a [Cluster]