Struct tinychain::cluster::Cluster[][src]

pub struct Cluster { /* fields omitted */ }
The data structure responsible for maintaining consensus per-transaction.

Implementations

Borrow one of this cluster’s Chains.

Borrow an InstanceClass, if there is one defined with the given name.

Borrow the public key of this cluster.

Return the canonical Link to this cluster (probably not on this host).

Return the path of this cluster, relative to this host.

Return the names of the members of this cluster.

Iterate over a list of replicas of this cluster.

Claim ownership of the given Txn.

Return Unauthorized if the request does not have the given scope from a trusted issuer.

Grant the given scope to the txn and use it to resolve the given OpRef.

Trust the Cluster at the given Link to issue the given auth Scopes.

Claim leadership of the given Txn.

Add a replica to this cluster.

Remove a replica from this cluster.