Maintains the consistency of the network by coordinating transaction commits.
Re-exports
pub use class::Class;pub use dir::Dir;pub use dir::DirEntry;pub use dir::DirItem;pub use library::Library;pub use service::Service;
Modules
Structs
- The data structure responsible for maintaining consensus per-transaction across the network.
- The static configuration of a
Cluster
Constants
- The name of the endpoint which serves a [
Link] to each of this [Cluster]’s replicas.
Traits
- A state which supports replication in a [
Cluster]