Struct tinychain::cluster::Cluster [−][src]
pub struct Cluster { /* fields omitted */ }Expand description
The data structure responsible for maintaining consensus per-transaction.
Implementations
Borrow an InstanceClass, if there is one defined with the given name.
Borrow the public key of this cluster.
Return the canonical Link to this cluster (probably not on this host).
Return the path of this cluster, relative to this host.
Iterate over a list of replicas of this cluster.
Return Unauthorized if the request does not have the given scope from a trusted issuer.
Grant the given scope to the txn and use it to resolve the given OpRef.
Add a replica to this cluster.
Remove a replica from this cluster.